# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Custom controller for current user page."""

from twisted.internet.defer import inlineCallbacks

from ubuntu_sso.qt import controllers

from ubuntuone.platform.credentials import (
     CredentialsManagementTool,
     CredentialsError,
)

from ubuntuone_installer.logger import setup_logging

# Invalid name logger
# pylint: disable=C0103
logger = setup_logging('qt.currentuser')
# pylint: enable=C0103


class CurrentUserController(controllers.CurrentUserController):
    """Custom controller for current user page."""

    @inlineCallbacks
    def login(self, *args):
        """Perform the login using the self.backend."""
        email = unicode(self.view.ui.email_edit.text())
        password = unicode(self.view.ui.password_edit.text())
        credtool = CredentialsManagementTool()
        try:
            d = yield credtool.login_email_password(
                email=email,
                password=password,
            )
            self.on_logged_in(self.view.wizard().app_name, d)
        except CredentialsError, e:
            logger.exception("Error getting credentials:")
            self.on_login_error(e.args[0])
