# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Wizard's side widget."""

from PyQt4 import QtGui

from ubuntuone_installer.gui.qt.ui import side_widget_ui
# Module used ti include the resources into this file
# pylint: disable=W0611
from ubuntuone_installer.gui.qt.ui import images_rc
# pylint: enable=W0611


class SideWidget(QtGui.QFrame):

    """Wizard's side widget."""

    install_stage = 0
    signin_stage = 1
    choose_services_stage = 2
    select_sync_folders_stage = 3
    sync_stage = 4

    def __init__(self, *args, **kwargs):
        super(SideWidget, self).__init__(*args, **kwargs)
        self.ui = side_widget_ui.Ui_SideWidget()
        self.ui.setupUi(self)
        self.stage = 0

    def set_stage(self, stage):
        """Switch to the desired stage."""
        self.stage = stage
        self.ui.install_label.setEnabled(stage >= 0)
        self.ui.sign_in_label.setEnabled(stage >= 1)
        self.ui.choose_services_label.setEnabled(stage >= 2)
        self.ui.select_folders_label.setEnabled(stage >= 3)
        self.ui.sync_label.setEnabled(stage >= 4)
        self.set_stage_icon(self.ui.install_icon_label, self.install_stage)
        self.set_stage_icon(self.ui.sign_icon_label, self.signin_stage)
        self.set_stage_icon(self.ui.choose_icon_label,
            self.choose_services_stage)
        self.set_stage_icon(self.ui.folders_icon_label,
            self.select_sync_folders_stage)
        self.set_stage_icon(self.ui.sync_icon_label, self.sync_stage)

    def set_stage_icon(self, label, label_stage):
        """Set the label icon depending on the proper state."""
        if self.stage == label_stage and label == self.ui.sync_icon_label:
            label.setPixmap(QtGui.QPixmap(":/progress_finish_orange.png"))
        elif self.stage == label_stage:
            label.setPixmap(QtGui.QPixmap(":/progress_arrow_orange.png"))
        elif self.stage > label_stage:
            label.setPixmap(QtGui.QPixmap(":/progress_tick.png"))
        elif label == self.ui.sync_icon_label:
            label.setPixmap(QtGui.QPixmap(":/progress_finish_grey.png"))
        else:
            label.setPixmap(QtGui.QPixmap(":/progress_arrow_grey.png"))
