# -*- coding: utf-8 -*-

# Authors: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The test suite for the Qt UI of the Ubuntu One Installer."""

from ubuntuone_installer.tests import TestCase
from ubuntuone_installer.gui.tests import FakedObject

# Attribute 'yyy' defined outside __init__, access to a protected member
# pylint: disable=W0201, W0212


NO_OP = lambda *args: None


def skip_if_abstract_class(test):
    """Decorator to skip a test if is an abstract class."""

    def inner(instance):
        """Skip a test if is an abstract class."""
        abstract = instance.class_ui is None
        result = None
        if not abstract:
            result = test(instance)

        return result

    return inner


class FakeUi(FakedObject):
    """A fake Ui object."""

    exposed_methods = ['setupUi']


class BaseTestCase(TestCase):
    """Base Test Case."""

    class_ui = None
    kwargs = {}

    @skip_if_abstract_class
    def setUp(self):
        super(BaseTestCase, self).setUp()
        # self.class_ui is not callable
        # pylint: disable=E1102
        # pylint: disable=C0103
        self.ui = self.class_ui(**self.kwargs)

        if hasattr(self.ui, 'backend'):
            # clean backend calls
            self.ui.backend._called.clear()
