# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the CurrentUserController."""

from ubuntuone_installer.gui.qt import currentuser
from ubuntuone_installer.gui.qt.tests import BaseTestCase


class FakeView(object):

    """A Fake view for the controller."""

    def __init__(self):
        """Setup."""
        self.view = self
        self.ui = self
        self.email_edit = self
        self.password_edit = self
        self.app_name = "APP"

    def text(self):
        """Return some text."""
        return "text"

    def wizard(self):
        """Fake the wizard() method of QWizardPage."""
        return self


class FakeCredentialsManagementToolSuccess(object):

    """A fake CredentialsManagementTool where login succeeds."""

    def login_email_password(self, *args, **kwargs):
        """Fake credentials."""
        return {"x": "y"}


class FakeCredentialsManagementToolFailure(object):

    """A fake CredentialsManagementTool where login fails."""

    def login_email_password(self, *args, **kwargs):
        """Raises a credentials exception."""
        raise currentuser.CredentialsError("Failure")


class CurrentUserTestCase(BaseTestCase):

    """Test the CurrentUserController."""

    class_ui = FakeView

    def setUp(self):
        """Initialize this test instance."""
        self.controller = currentuser.CurrentUserController()
        self.controller.view = FakeView()
        super(CurrentUserTestCase, self).setUp()

    def test_login_success(self):
        """Check that login works correctly."""
        self.patch(currentuser, 'CredentialsManagementTool',
            FakeCredentialsManagementToolSuccess)
        self.patch(self.controller, 'on_logged_in', self._set_called)
        self.controller.login()
        self.assertEqual(self._called, (('APP', {'x': 'y'}), {}))

    def test_login_failure(self):
        """Check that login fails correctly."""
        self.patch(currentuser, 'CredentialsManagementTool',
            FakeCredentialsManagementToolFailure)
        self.patch(self.controller, 'on_login_error', self._set_called)
        self.controller.login()
        self.assertEqual(self._called, (('Failure',), {}))
