# -*- coding: utf-8 -*-

# Authors: Alejandro J. Cura <alecu@canonical.com>
#          Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the Qt UI."""

from PyQt4 import QtGui, QtCore

from ubuntuone_installer.gui.qt.tests import BaseTestCase
from ubuntuone_installer.gui.qt.side_widget import SideWidget
# Module used ti include the resources into this file
# pylint: disable=W0611
from ubuntuone_installer.gui.qt.ui import images_rc
# pylint: enable=W0611


class SideWidgetTestCase(BaseTestCase):

    """Test the qt main window."""

    class_ui = SideWidget

    def test_stage_0(self):
        """Check that each stage in the widget enables the right labels."""
        self.ui.set_stage(0)
        self.assertEqual(
            self.ui.ui.install_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.sign_in_label.isEnabled(), False)
        self.assertEqual(
            self.ui.ui.choose_services_label.isEnabled(), False)
        self.assertEqual(
            self.ui.ui.select_folders_label.isEnabled(), False)
        self.assertEqual(
            self.ui.ui.sync_label.isEnabled(), False)
        self.check_state_pixmap(0)

    def test_stage_1(self):
        """Check that each stage in the widget enables the right labels."""
        self.ui.set_stage(1)
        self.assertEqual(
            self.ui.ui.install_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.sign_in_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.choose_services_label.isEnabled(), False)
        self.assertEqual(
            self.ui.ui.select_folders_label.isEnabled(), False)
        self.assertEqual(
            self.ui.ui.sync_label.isEnabled(), False)
        self.check_state_pixmap(1)

    def test_stage_2(self):
        """Check that each stage in the widget enables the right labels."""
        self.ui.set_stage(2)
        self.assertEqual(
            self.ui.ui.install_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.sign_in_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.choose_services_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.select_folders_label.isEnabled(), False)
        self.assertEqual(
            self.ui.ui.sync_label.isEnabled(), False)
        self.check_state_pixmap(2)

    def test_stage_3(self):
        """Check that each stage in the widget enables the right labels."""
        self.ui.set_stage(3)
        self.assertEqual(
            self.ui.ui.install_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.sign_in_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.choose_services_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.select_folders_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.sync_label.isEnabled(), False)
        self.check_state_pixmap(3)

    def test_stage_4(self):
        """Check that each stage in the widget enables the right labels."""
        self.ui.set_stage(4)
        self.assertEqual(
            self.ui.ui.install_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.sign_in_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.choose_services_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.select_folders_label.isEnabled(), True)
        self.assertEqual(
            self.ui.ui.sync_label.isEnabled(), True)
        self.check_state_pixmap(4)

    def get_pixmap_data(self, pixmap):
        """Get the raw data of a QPixmap."""
        byte_array = QtCore.QByteArray()
        array_buffer = QtCore.QBuffer(byte_array)
        pixmap.save(array_buffer, "PNG")
        return byte_array

    # Invalid name "assertEqualPixmap"
    # pylint: disable=C0103

    def assertEqualPixmaps(self, pixmap1, pixmap2):
        """Compare two Qt pixmaps."""
        d1 = self.get_pixmap_data(pixmap1)
        d2 = self.get_pixmap_data(pixmap2)
        self.assertEqual(d1, d2)

    def check_state_pixmap(self, stage):
        """Check if each label has the proper pixmap depending on the state."""
        print stage
        active_pixmap = QtGui.QPixmap(":/progress_arrow_orange.png")
        no_active_pixmap = QtGui.QPixmap(":/progress_arrow_grey.png")
        complete_pixmap = QtGui.QPixmap(":/progress_tick.png")
        sync_active_pixmap = QtGui.QPixmap(":/progress_finish_orange.png")
        sync_no_active_pixmap = QtGui.QPixmap(":/progress_finish_grey.png")
        labels = (
            self.ui.ui.install_icon_label,
            self.ui.ui.sign_icon_label,
            self.ui.ui.choose_icon_label,
            self.ui.ui.folders_icon_label,
            self.ui.ui.sync_icon_label)

        for item in labels[:stage]:
            self.assertEqualPixmaps(complete_pixmap, item.pixmap())

        if stage != 4:
            self.assertEqualPixmaps(active_pixmap, labels[stage].pixmap())
        else:
            self.assertEqualPixmaps(sync_active_pixmap, labels[4].pixmap())

        if stage < 4:
            for item in labels[stage + 1:len(labels) - 1]:
                self.assertEqualPixmaps(no_active_pixmap, item.pixmap())
            self.assertEqualPixmaps(sync_no_active_pixmap, labels[4].pixmap())
